==> types_boto3_full-1.35.74-py3-none-any.whl: types_boto3_elb/waiter.py <==
"""
Type annotations for elb service client waiters.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_elb/waiters/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_elb.client import ElasticLoadBalancingClient
    from types_boto3_elb.waiter import (
        AnyInstanceInServiceWaiter,
        InstanceDeregisteredWaiter,
        InstanceInServiceWaiter,
    )

    session = Session()
    client: ElasticLoadBalancingClient = session.client("elb")

    any_instance_in_service_waiter: AnyInstanceInServiceWaiter = client.get_waiter("any_instance_in_service")
    instance_deregistered_waiter: InstanceDeregisteredWaiter = client.get_waiter("instance_deregistered")
    instance_in_service_waiter: InstanceInServiceWaiter = client.get_waiter("instance_in_service")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys

from botocore.waiter import Waiter

from .type_defs import (
    DescribeEndPointStateInputAnyInstanceInServiceWaitTypeDef,
    DescribeEndPointStateInputInstanceDeregisteredWaitTypeDef,
    DescribeEndPointStateInputInstanceInServiceWaitTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("AnyInstanceInServiceWaiter", "InstanceDeregisteredWaiter", "InstanceInServiceWaiter")


class AnyInstanceInServiceWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb/waiter/AnyInstanceInService.html#ElasticLoadBalancing.Waiter.AnyInstanceInService)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_elb/waiters/#anyinstanceinservicewaiter)
    """

    def wait(
        self, **kwargs: Unpack[DescribeEndPointStateInputAnyInstanceInServiceWaitTypeDef]
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb/waiter/AnyInstanceInService.html#ElasticLoadBalancing.Waiter.AnyInstanceInService.wait)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_elb/waiters/#anyinstanceinservicewaiter)
        """


class InstanceDeregisteredWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb/waiter/InstanceDeregistered.html#ElasticLoadBalancing.Waiter.InstanceDeregistered)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_elb/waiters/#instancederegisteredwaiter)
    """

    def wait(
        self, **kwargs: Unpack[DescribeEndPointStateInputInstanceDeregisteredWaitTypeDef]
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb/waiter/InstanceDeregistered.html#ElasticLoadBalancing.Waiter.InstanceDeregistered.wait)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_elb/waiters/#instancederegisteredwaiter)
        """


class InstanceInServiceWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb/waiter/InstanceInService.html#ElasticLoadBalancing.Waiter.InstanceInService)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_elb/waiters/#instanceinservicewaiter)
    """

    def wait(
        self, **kwargs: Unpack[DescribeEndPointStateInputInstanceInServiceWaitTypeDef]
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb/waiter/InstanceInService.html#ElasticLoadBalancing.Waiter.InstanceInService.wait)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_elb/waiters/#instanceinservicewaiter)
        """

==> types_boto3_full-1.35.91-py3-none-any.whl: types_boto3_elb/waiter.py <==
"""
Type annotations for elb service client waiters.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_elb/waiters/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_elb.client import ElasticLoadBalancingClient
    from types_boto3_elb.waiter import (
        AnyInstanceInServiceWaiter,
        InstanceDeregisteredWaiter,
        InstanceInServiceWaiter,
    )

    session = Session()
    client: ElasticLoadBalancingClient = session.client("elb")

    any_instance_in_service_waiter: AnyInstanceInServiceWaiter = client.get_waiter("any_instance_in_service")
    instance_deregistered_waiter: InstanceDeregisteredWaiter = client.get_waiter("instance_deregistered")
    instance_in_service_waiter: InstanceInServiceWaiter = client.get_waiter("instance_in_service")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys

from botocore.waiter import Waiter

from .type_defs import DescribeEndPointStateInputWaitTypeDef

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("AnyInstanceInServiceWaiter", "InstanceDeregisteredWaiter", "InstanceInServiceWaiter")


class AnyInstanceInServiceWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb/waiter/AnyInstanceInService.html#ElasticLoadBalancing.Waiter.AnyInstanceInService)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_elb/waiters/#anyinstanceinservicewaiter)
    """

    def wait(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeEndPointStateInputWaitTypeDef]
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb/waiter/AnyInstanceInService.html#ElasticLoadBalancing.Waiter.AnyInstanceInService.wait)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_elb/waiters/#anyinstanceinservicewaiter)
        """


class InstanceDeregisteredWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb/waiter/InstanceDeregistered.html#ElasticLoadBalancing.Waiter.InstanceDeregistered)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_elb/waiters/#instancederegisteredwaiter)
    """

    def wait(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeEndPointStateInputWaitTypeDef]
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb/waiter/InstanceDeregistered.html#ElasticLoadBalancing.Waiter.InstanceDeregistered.wait)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_elb/waiters/#instancederegisteredwaiter)
        """


class InstanceInServiceWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb/waiter/InstanceInService.html#ElasticLoadBalancing.Waiter.InstanceInService)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_elb/waiters/#instanceinservicewaiter)
    """

    def wait(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeEndPointStateInputWaitTypeDef]
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb/waiter/InstanceInService.html#ElasticLoadBalancing.Waiter.InstanceInService.wait)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_elb/waiters/#instanceinservicewaiter)
        """
